@@ -12,7 +12,7 @@ import re
 import codecs
 from sutekh.io.SutekhBaseHTMLParser import LogStateWithInfo
 from logging import Logger
-from sutekh.core.SutekhObjects import SutekhObjectMaker
+from sutekh.core.SutekhObjects import SutekhObjectMaker, csv_to_canonical
 
 
 def strip_braces(sText):
@@ -147,8 +147,11 @@ class CardDict(dict):
     # equipment properties
     dEquipmentProperties = {
             'unique': re.compile('Unique (melee )?weapon|Unique equipment|'
-                'represents a unique location'),
-            'location': re.compile('represents a (unique )?location'),
+                'represents a unique location|'
+                'this is a unique location|'
+                'as equipment (while|when) in play. (Haven. )?Unique.'),
+            'location': re.compile('represents a (unique )?location|'
+                'this is a (unique )?location'),
             'melee weapon': re.compile('[mM]elee weapon\.'),
             'cold iron': re.compile('weapon\. Cold iron\.'),
             'gun': re.compile('[wW]eapon[:,.] [gG]un\.'),
@@ -435,7 +438,7 @@ class CardDict(dict):
         """Add the group to the card. Replace '*' with -1."""
         sGroup = self.oWhiteSp.sub(' ', sGroup).strip()
 
-        if sGroup == '*':
+        if sGroup == '*' or sGroup.lower() == 'any':
             iGroup = -1
         else:
             iGroup = int(sGroup, 10)
@@ -612,7 +615,9 @@ class WaitingForCardName(LogStateWithInfo):
         if sLine.startswith('Name:'):
             self.flush()
             sData = sLine.split(':', 1)[1]
-            self._dInfo['name'] = sData.strip()
+            # CSV style names sometimes creep into the cardlist.txt,
+            # so ensure we normalise them consistently
+            self._dInfo['name'] = csv_to_canonical(sData.strip())
             return InExpansion(self._dInfo, self.oLogger)
         elif sLine.strip():
             if self._dInfo.has_key('name') and not self._dInfo.has_key('text'):
